pub struct ChannelWithTeamData {Show 18 fields
pub id: Option<String>,
pub create_at: Option<i64>,
pub update_at: Option<i64>,
pub delete_at: Option<i64>,
pub team_id: Option<String>,
pub type: Option<String>,
pub display_name: Option<String>,
pub name: Option<String>,
pub header: Option<String>,
pub purpose: Option<String>,
pub last_post_at: Option<i32>,
pub total_msg_count: Option<i32>,
pub extra_update_at: Option<i64>,
pub creator_id: Option<String>,
pub team_display_name: Option<String>,
pub team_name: Option<String>,
pub team_update_at: Option<i32>,
pub policy_id: Option<String>,
}Fields
id: Option<String>create_at: Option<i64>The time in milliseconds a channel was created
update_at: Option<i64>The time in milliseconds a channel was last updated
delete_at: Option<i64>The time in milliseconds a channel was deleted
team_id: Option<String>type: Option<String>display_name: Option<String>name: Option<String>header: Option<String>purpose: Option<String>last_post_at: Option<i32>The time in milliseconds of the last post of a channel
total_msg_count: Option<i32>extra_update_at: Option<i64>Deprecated in Mattermost 5.0 release
creator_id: Option<String>team_display_name: Option<String>The display name of the team to which this channel belongs.
team_name: Option<String>The name of the team to which this channel belongs.
team_update_at: Option<i32>The time at which the team to which this channel belongs was last updated.
policy_id: Option<String>The data retention policy to which this team has been assigned. If no such policy exists, or the caller does not have the sysconsole_read_compliance_data_retention permission, this field will be null.
Implementations
Sourceimpl ChannelWithTeamData
impl ChannelWithTeamData
pub fn new() -> ChannelWithTeamData