pub struct DataRetentionPolicyCreate {
pub display_name: String,
pub post_duration: i32,
pub team_ids: Option<Vec<String>>,
pub channel_ids: Option<Vec<String>>,
}Fields
display_name: StringThe display name for this retention policy.
post_duration: i32The number of days a message will be retained before being deleted by this policy. If this value is less than 0, the policy has infinite retention (i.e. messages are never deleted).
team_ids: Option<Vec<String>>The IDs of the teams to which this policy should be applied.
channel_ids: Option<Vec<String>>The IDs of the channels to which this policy should be applied.
Implementations
Sourceimpl DataRetentionPolicyCreate
impl DataRetentionPolicyCreate
pub fn new( display_name: String, post_duration: i32, ) -> DataRetentionPolicyCreate