pub struct Role {
pub id: Option<String>,
pub name: Option<String>,
pub display_name: Option<String>,
pub description: Option<String>,
pub permissions: Option<Vec<String>>,
pub scheme_managed: Option<bool>,
}Fields
id: Option<String>The unique identifier of the role.
name: Option<String>The unique name of the role, used when assigning roles to users/groups in contexts.
display_name: Option<String>The human readable name for the role.
description: Option<String>A human readable description of the role.
permissions: Option<Vec<String>>A list of the unique names of the permissions this role grants.
scheme_managed: Option<bool>indicates if this role is managed by a scheme (true), or is a custom stand-alone role (false).
Implementations