pub struct SearchUsersRequest {
pub term: String,
pub team_id: Option<String>,
pub not_in_team_id: Option<String>,
pub in_channel_id: Option<String>,
pub not_in_channel_id: Option<String>,
pub in_group_id: Option<String>,
pub group_constrained: Option<bool>,
pub allow_inactive: Option<bool>,
pub without_team: Option<bool>,
pub limit: Option<i32>,
}Fields
term: StringThe term to match against username, full name, nickname and email
team_id: Option<String>If provided, only search users on this team
not_in_team_id: Option<String>If provided, only search users not on this team
in_channel_id: Option<String>If provided, only search users in this channel
not_in_channel_id: Option<String>If provided, only search users not in this channel. Must specifiy team_id when using this option
in_group_id: Option<String>If provided, only search users in this group. Must have manage_system permission.
group_constrained: Option<bool>When used with not_in_channel_id or not_in_team_id, returns only the users that are allowed to join the channel or team based on its group constrains.
allow_inactive: Option<bool>When true, include deactivated users in the results
without_team: Option<bool>Set this to true if you would like to search for users that are not on a team. This option takes precendence over team_id, in_channel_id, and not_in_channel_id.
limit: Option<i32>The maximum number of users to return in the results Available as of server version 5.6. Defaults to 100 if not provided or on an earlier server version.
Implementations
Sourceimpl SearchUsersRequest
impl SearchUsersRequest
pub fn new(term: String) -> SearchUsersRequest